@@ -9,8 +9,10 @@ Aws configuration iiles should be present:
 """
 
 
-def list_s3_bucket(profile_name: str = 'terraform',
-                   region_name: str = 'us-east-2') -> [str]:
+def list_s3_bucket(
+        profile_name: str = 'terraform',
+        region_name: str = 'us-east-1'
+) -> [str]:
     """This function list all AWS S3 bucket how can access the profile
     profile_name in the AWS region region_name.
 
